@@ -2,7 +2,7 @@
 Functionality specific to build scripts.
 """
 
-from . import * #pylint: disable=unused-wildcard-import
+from . import *  # pylint: disable=unused-wildcard-import
 
 from ruamel.yaml import YAML
 from munch import munchify
@@ -13,18 +13,20 @@ class _BuildState:
         self.config = None
         self.envconfig = None
 
+
 _BUILD_STATE = _BuildState()
 
-ENV = envarg('ENV', description="build environment, e.g. dev, test, prod")
+ENV = envarg("ENV", description="build environment, e.g. dev, test, prod")
 
-#region Build script functions
+# region Build script functions
 
-def load_config(path = os.path.join(PROJECT_PATH, 'build.yaml')) -> Any:
+
+def load_config(path=os.path.join(PROJECT_PATH, "build.yaml")) -> Any:
     """Loads configuration from path.
-    
+
     Arguments:
         path {str} -- Path to configuration file. (default: {PROJECT_PATH/build.yaml})
-    
+
     Returns:
         Any -- Configuration dictionary or list (supports munch attribute notation).
     """
@@ -34,7 +36,7 @@ def load_config(path = os.path.join(PROJECT_PATH, 'build.yaml')) -> Any:
         print("Config {} not found".format(path))
         raise ValueError("Config not found!")
 
-    with open(path, 'r') as stream:
+    with open(path, "r") as stream:
         try:
             yaml = YAML()
             yaml.preserve_quotes = True
@@ -42,36 +44,38 @@ def load_config(path = os.path.join(PROJECT_PATH, 'build.yaml')) -> Any:
             config = munchify(config)
         except yaml.scanner.ScannerError as exc:
             print("Cannot parse config {}: {}".format(path, exc))
-    
+
     _BUILD_STATE.config = config
     return config
 
-def config(keys: list = [], required = True) -> Any:
+
+def config(keys: list = [], required=True) -> Any:
     """Loads configuration from file or returns previously loaded one.
 
     Loading from file will be done on the first call.
-    
+
     Arguments:
         keys {list} -- List of recursive keys to retrieve.
 
     Keyword Arguments:
         required {bool} -- Throws fatal error if not found, when set to True (default: {True})
-    
+
     Returns:
         Any -- Loaded configuration dict, list (support munch attribute notation) or None.
     """
 
     v = _BUILD_STATE.config if _BUILD_STATE.config else load_config()
-    
+
     if len(keys) > 0:
         v = getpath(v, keys)
         if required and v == None:
-            safe_keys = map(lambda x: x if x != None else 'None', keys)
-            logging.critical("Cannot find %s in configuration", '->'.join(safe_keys))
+            safe_keys = map(lambda x: x if x != None else "None", keys)
+            logging.critical("Cannot find %s in configuration", "->".join(safe_keys))
 
     return v.copy() if isinstance(v, dict) or isinstance(v, list) else v
 
-def load_envconfig(root = 'Environments', inherit = 'Inherit') -> dict:
+
+def load_envconfig(root="Environments", inherit="Inherit") -> dict:
     """Loads environment-specific configuration.
 
     Environment-specific configuration is part of regular configuration, it's just
@@ -79,11 +83,11 @@ def load_envconfig(root = 'Environments', inherit = 'Inherit') -> dict:
     to current running environment.
 
     It also allows keys to be inherited by the environment name.
-    
+
     Keyword Arguments:
         root {str} -- Name of root element containing environment-specific configuration. (default: {'Environments'})
         inherit {str} -- Name of parameter containing environment to inherit from. (default: {'Inherit'})
-    
+
     Returns:
         dict -- Loaded configuration dictionary (supports munch attribute notation).
     """
@@ -93,11 +97,12 @@ def load_envconfig(root = 'Environments', inherit = 'Inherit') -> dict:
         fields = config([root, envconfig.pop(inherit)])
         fields = {k: v for k, v in fields.items() if k not in envconfig}
         envconfig.update(fields)
-    
+
     _BUILD_STATE.envconfig = envconfig
     return envconfig
 
-def envconfig(keys = []) -> dict:
+
+def envconfig(keys=[]) -> dict:
     """Loads environment-specific configuration or returns previously loaded one.
 
     Environment-specific configuration is part of regular configuration, it's just
@@ -105,27 +110,28 @@ def envconfig(keys = []) -> dict:
     to current running environment.
 
     It also allows keys to be inherited by the environment name.
-    
+
     Keyword Arguments:
         keys {list} -- List of recursive keys to retrieve. (default: {[]})
-    
+
     Returns:
         dict -- Loaded configuration dictionary (supports munch attribute notation).
     """
 
     v = _BUILD_STATE.envconfig if _BUILD_STATE.envconfig else load_envconfig()
-    
+
     v = getpath(v, keys)
 
     return v.copy() if isinstance(v, dict) or isinstance(v, list) else v
 
+
 def getpath(x: Any, keys: list) -> Any:
     """Gets recursive key path from dictionary or list.
-    
+
     Arguments:
         x {Any} -- Dictionary or list.
         keys {list} -- List of recursive keys to retrieve.
-    
+
     Returns:
         Any -- Retrieved dictionary, list or None.
     """
@@ -142,16 +148,17 @@ def getpath(x: Any, keys: list) -> Any:
         x = x[key]
     return x
 
-def flatten(x: dict, prefix = '', grouped = True) -> dict:
+
+def flatten(x: dict, prefix="", grouped=True) -> dict:
     """Flattens dictionary by a group (one level only).
-    
+
     Arguments:
         x {dict} -- Dictionary to be flattened.
-    
+
     Keyword Arguments:
         prefix {str} -- Group prefix to flatten by. (default: {''})
         grouped (bool) -- True if parameters are internally grouped by key. (default: {True})
-    
+
     Returns:
         dict -- New flattened dictionary.
     """
@@ -169,31 +176,38 @@ def flatten(x: dict, prefix = '', grouped = True) -> dict:
         flatten_inner(x, output, prefix)
     return output
 
+
 def git_hash() -> str:
     """Extracts Git hash from current directory.
-    
+
     Returns:
         str -- Git hash encoded as UTF-8.
     """
 
-    return subprocess.Popen(['git', 'rev-parse', '--verify', 'HEAD'], stdout=subprocess.PIPE) \
-        .communicate()[0] \
-        .decode('utf-8') \
-        .replace('\n', '')
+    return (
+        subprocess.Popen(
+            ["git", "rev-parse", "--verify", "HEAD"], stdout=subprocess.PIPE
+        )
+        .communicate()[0]
+        .decode("utf-8")
+        .replace("\n", "")
+    )
 
 
 def md5(*files: list) -> str:
     """Computes MD5 checksum of files.
-    
+
     Returns:
         str -- Combined MD5 checksum for multiple files.
     """
 
     import hashlib
+
     hash = hashlib.md5()
     for f in files:
         if os.path.isfile(f):
-            hash.update(open(f, 'rb').read())
+            hash.update(open(f, "rb").read())
     return hash.hexdigest()
 
-#endregion
+
+# endregion
